@@ -14,6 +14,10 @@ from ecs_composex.common.aws import (
     BUCKET_NAME, CURATED_AZS
 )
 from ecs_composex.common import KEYISSET
+from ecs_composex.common.cfn_tools import (
+    build_config_template_file,
+    write_config_template_file
+)
 from ecs_composex.root import generate_full_template
 from ecs_composex.vpc.vpc_params import (
     APP_SUBNETS_T, PUBLIC_SUBNETS_T, STORAGE_SUBNETS_T,
@@ -42,13 +46,13 @@ def validate_vpc_input(args):
     if not KEYISSET('CreateVpc', args):
         for key in nocreate_requirements:
             if not KEYISSET(key, args):
-                raise ValueError(f"If you want to use an existing VPC, you need {key}")
+                warnings.warn(f"{key} was not provided. Not adding to the parameters file", UserWarning)
     else:
         for key in nocreate_requirements:
             if KEYISSET(key, args):
                 LOG.info(args[key])
                 warnings.warn(
-                    f"Creating VPC is set but you also set {key}. Ignoring and using new VPC values",
+                    f"Creating VPC is set. Ignoring value for {key}",
                     UserWarning
                 )
 
@@ -60,7 +64,9 @@ def validate_cluster_input(args):
     :raise: KeyError
     """
     if not KEYISSET('CreateCluster', args) and not KEYISSET(CLUSTER_NAME_T, args):
-        raise KeyError(f"You must provide an ECS Cluster name if you do not want ECS ComposeX to create one for you")
+        warnings.warn(
+            f"You must provide an ECS Cluster name if you do not want ECS ComposeX to create one for you", UserWarning
+        )
 
 
 def main():
@@ -76,6 +82,13 @@ def main():
         help="The name and path of the main output file. If you specify extra arguments, it will create a parameters"
              " file as well for creating your CFN Stack"
     )
+    parser.add_argument(
+        '--cfn-config-file', help="Path to AWS Template config file", required=False, dest="CfnConfigFile", type=str
+    )
+    parser.add_argument(
+        '--no-cfn-template-config-file', action='store_true', default=True,
+        help="Do not generate the CFN Configuration template file"
+    )
     #  AWS SETTINGS
     parser.add_argument(
         '--region', required=False, default=session.Session().region_name,
@@ -158,6 +171,12 @@ def main():
     print("Arguments: " + str(args._))
     templates_and_params = generate_full_template(**vars(args))
     write_template_to_file(templates_and_params[0], args.output_file)
+    cfn_config = build_config_template_file(templates_and_params[1])
+    if KEYISSET('CfnConfigFile', vars(args)):
+        config_file_path = args.CfnConfigFile
+    else:
+        config_file_path = f"{args.output_file.split('.')[0]}.config.json"
+    write_config_template_file(cfn_config, config_file_path)
     with open(f"{args.output_file.split('.')[0]}.params.json", 'w') as params_fd:
         params_fd.write(json.dumps(templates_and_params[1], indent=4))
 
